==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkCursor3D.java <==
// java wrapper for vtkCursor3D object
//

package vtk;
import vtk.*;

public class vtkCursor3D extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetModelBounds_2(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetModelBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetModelBounds_2(id0,id1,id2,id3,id4,id5); }

  private native void SetModelBounds_3(double id0[]);
  public void SetModelBounds(double id0[])
    { SetModelBounds_3(id0); }

  private native double[] GetModelBounds_4();
  public double[] GetModelBounds()
    { return GetModelBounds_4(); }

  private native void SetFocalPoint_5(double id0[]);
  public void SetFocalPoint(double id0[])
    { SetFocalPoint_5(id0); }

  private native void SetFocalPoint_6(double id0,double id1,double id2);
  public void SetFocalPoint(double id0,double id1,double id2)
    { SetFocalPoint_6(id0,id1,id2); }

  private native double[] GetFocalPoint_7();
  public double[] GetFocalPoint()
    { return GetFocalPoint_7(); }

  private native void SetOutline_8(int id0);
  public void SetOutline(int id0)
    { SetOutline_8(id0); }

  private native int GetOutline_9();
  public int GetOutline()
    { return GetOutline_9(); }

  private native void OutlineOn_10();
  public void OutlineOn()
    { OutlineOn_10(); }

  private native void OutlineOff_11();
  public void OutlineOff()
    { OutlineOff_11(); }

  private native void SetAxes_12(int id0);
  public void SetAxes(int id0)
    { SetAxes_12(id0); }

  private native int GetAxes_13();
  public int GetAxes()
    { return GetAxes_13(); }

  private native void AxesOn_14();
  public void AxesOn()
    { AxesOn_14(); }

  private native void AxesOff_15();
  public void AxesOff()
    { AxesOff_15(); }

  private native void SetXShadows_16(int id0);
  public void SetXShadows(int id0)
    { SetXShadows_16(id0); }

  private native int GetXShadows_17();
  public int GetXShadows()
    { return GetXShadows_17(); }

  private native void XShadowsOn_18();
  public void XShadowsOn()
    { XShadowsOn_18(); }

  private native void XShadowsOff_19();
  public void XShadowsOff()
    { XShadowsOff_19(); }

  private native void SetYShadows_20(int id0);
  public void SetYShadows(int id0)
    { SetYShadows_20(id0); }

  private native int GetYShadows_21();
  public int GetYShadows()
    { return GetYShadows_21(); }

  private native void YShadowsOn_22();
  public void YShadowsOn()
    { YShadowsOn_22(); }

  private native void YShadowsOff_23();
  public void YShadowsOff()
    { YShadowsOff_23(); }

  private native void SetZShadows_24(int id0);
  public void SetZShadows(int id0)
    { SetZShadows_24(id0); }

  private native int GetZShadows_25();
  public int GetZShadows()
    { return GetZShadows_25(); }

  private native void ZShadowsOn_26();
  public void ZShadowsOn()
    { ZShadowsOn_26(); }

  private native void ZShadowsOff_27();
  public void ZShadowsOff()
    { ZShadowsOff_27(); }

  private native void SetTranslationMode_28(int id0);
  public void SetTranslationMode(int id0)
    { SetTranslationMode_28(id0); }

  private native int GetTranslationMode_29();
  public int GetTranslationMode()
    { return GetTranslationMode_29(); }

  private native void TranslationModeOn_30();
  public void TranslationModeOn()
    { TranslationModeOn_30(); }

  private native void TranslationModeOff_31();
  public void TranslationModeOff()
    { TranslationModeOff_31(); }

  private native void SetWrap_32(int id0);
  public void SetWrap(int id0)
    { SetWrap_32(id0); }

  private native int GetWrap_33();
  public int GetWrap()
    { return GetWrap_33(); }

  private native void WrapOn_34();
  public void WrapOn()
    { WrapOn_34(); }

  private native void WrapOff_35();
  public void WrapOff()
    { WrapOff_35(); }

  private native long GetFocus_36();
  public vtkPolyData GetFocus() {
    long temp = GetFocus_36();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void AllOn_37();
  public void AllOn()
    { AllOn_37(); }

  private native void AllOff_38();
  public void AllOff()
    { AllOff_38(); }

  public vtkCursor3D() { super(); }

  public vtkCursor3D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-aarch64.pkg.tar.xz: vtk/vtkCursor3D.java <==
// java wrapper for vtkCursor3D object
//

package vtk;
import vtk.*;

public class vtkCursor3D extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetModelBounds_2(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetModelBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetModelBounds_2(id0,id1,id2,id3,id4,id5); }

  private native void SetModelBounds_3(double id0[]);
  public void SetModelBounds(double id0[])
    { SetModelBounds_3(id0); }

  private native double[] GetModelBounds_4();
  public double[] GetModelBounds()
    { return GetModelBounds_4(); }

  private native void SetFocalPoint_5(double id0[]);
  public void SetFocalPoint(double id0[])
    { SetFocalPoint_5(id0); }

  private native void SetFocalPoint_6(double id0,double id1,double id2);
  public void SetFocalPoint(double id0,double id1,double id2)
    { SetFocalPoint_6(id0,id1,id2); }

  private native double[] GetFocalPoint_7();
  public double[] GetFocalPoint()
    { return GetFocalPoint_7(); }

  private native void SetOutline_8(int id0);
  public void SetOutline(int id0)
    { SetOutline_8(id0); }

  private native int GetOutline_9();
  public int GetOutline()
    { return GetOutline_9(); }

  private native void OutlineOn_10();
  public void OutlineOn()
    { OutlineOn_10(); }

  private native void OutlineOff_11();
  public void OutlineOff()
    { OutlineOff_11(); }

  private native void SetAxes_12(int id0);
  public void SetAxes(int id0)
    { SetAxes_12(id0); }

  private native int GetAxes_13();
  public int GetAxes()
    { return GetAxes_13(); }

  private native void AxesOn_14();
  public void AxesOn()
    { AxesOn_14(); }

  private native void AxesOff_15();
  public void AxesOff()
    { AxesOff_15(); }

  private native void SetXShadows_16(int id0);
  public void SetXShadows(int id0)
    { SetXShadows_16(id0); }

  private native int GetXShadows_17();
  public int GetXShadows()
    { return GetXShadows_17(); }

  private native void XShadowsOn_18();
  public void XShadowsOn()
    { XShadowsOn_18(); }

  private native void XShadowsOff_19();
  public void XShadowsOff()
    { XShadowsOff_19(); }

  private native void SetYShadows_20(int id0);
  public void SetYShadows(int id0)
    { SetYShadows_20(id0); }

  private native int GetYShadows_21();
  public int GetYShadows()
    { return GetYShadows_21(); }

  private native void YShadowsOn_22();
  public void YShadowsOn()
    { YShadowsOn_22(); }

  private native void YShadowsOff_23();
  public void YShadowsOff()
    { YShadowsOff_23(); }

  private native void SetZShadows_24(int id0);
  public void SetZShadows(int id0)
    { SetZShadows_24(id0); }

  private native int GetZShadows_25();
  public int GetZShadows()
    { return GetZShadows_25(); }

  private native void ZShadowsOn_26();
  public void ZShadowsOn()
    { ZShadowsOn_26(); }

  private native void ZShadowsOff_27();
  public void ZShadowsOff()
    { ZShadowsOff_27(); }

  private native void SetTranslationMode_28(int id0);
  public void SetTranslationMode(int id0)
    { SetTranslationMode_28(id0); }

  private native int GetTranslationMode_29();
  public int GetTranslationMode()
    { return GetTranslationMode_29(); }

  private native void TranslationModeOn_30();
  public void TranslationModeOn()
    { TranslationModeOn_30(); }

  private native void TranslationModeOff_31();
  public void TranslationModeOff()
    { TranslationModeOff_31(); }

  private native void SetWrap_32(int id0);
  public void SetWrap(int id0)
    { SetWrap_32(id0); }

  private native int GetWrap_33();
  public int GetWrap()
    { return GetWrap_33(); }

  private native void WrapOn_34();
  public void WrapOn()
    { WrapOn_34(); }

  private native void WrapOff_35();
  public void WrapOff()
    { WrapOff_35(); }

  private native long GetFocus_36();
  public vtkPolyData GetFocus() {
    long temp = GetFocus_36();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void AllOn_37();
  public void AllOn()
    { AllOn_37(); }

  private native void AllOff_38();
  public void AllOff()
    { AllOff_38(); }

  public vtkCursor3D() { super(); }

  public vtkCursor3D(long id) { super(id); }
  public native long   VTKInit();

}
